@@ -1,5 +1,5 @@
 /* This file is part of the YAZ toolkit.
- * Copyright (C) 1995-2008 Index Data.
+ * Copyright (C) 1995-2009 Index Data.
  * All rights reserved.
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -151,6 +151,7 @@ ZOOM_connection_last_event(ZOOM_connection cs);
 #define ZOOM_EVENT_RECV_RECORD 8
 #define ZOOM_EVENT_RECV_SEARCH 9
 #define ZOOM_EVENT_END 10
+#define ZOOM_EVENT_MAX 10
 
 /* ----------------------------------------------------------- */
 /* result sets */
@@ -486,10 +487,15 @@ ZOOM_API(int)
 ZOOM_API(int)
     ZOOM_connection_peek_event(ZOOM_connection c);
 
+ZOOM_API(const char *)
+    ZOOM_get_event_str(int event);
+
 ZOOM_END_CDECL
+
 /*
  * Local variables:
  * c-basic-offset: 4
+ * c-file-style: "Stroustrup"
  * indent-tabs-mode: nil
  * End:
  * vim: shiftwidth=4 tabstop=8 expandtab
